import { spawn } from 'node:child_process';
import { run } from './outputs.js';
/**
 * Run child process and returns stdout and stderr to user stout
 */
const spawnPromised = async (cmd, args, opts) => {
    // NOTE: Pipes stderr, stdout to main process
    const childProcess = spawn(cmd, args, {
        ...opts,
        stdio: process.env.APIFY_NO_LOGS_IN_TESTS ? 'ignore' : 'inherit',
    });
    // Catch ctrl-c (SIGINT) and kills child process
    // NOTE: This fix kills also puppeteer child node process
    process.on('SIGINT', () => {
        try {
            childProcess.kill();
        }
        catch {
            // SIGINT can come after the child process is finished, ignore it
        }
    });
    return new Promise((resolve, reject) => {
        childProcess.on('error', reject);
        childProcess.on('close', (code) => {
            if (code !== 0)
                reject(new Error(`${cmd} exited with code ${code}`));
            resolve();
        });
    });
};
export async function execWithLog(cmd, args = [], opts = {}) {
    run(`${cmd} ${args.join(' ')}`);
    await spawnPromised(cmd, args, opts);
}
//# sourceMappingURL=exec.js.map